@@ -233,13 +233,14 @@ double min_xy(double x, double y);
 void minvec(const double *x, int ini, int fi, double *xmin, int *minpos); //min of a vector and position at which min occurs
 void maxvec(const double *x, int ini, int fi, double *xmax, int *maxpos); //max of a vector and position at which max occurs
 
+void make_posdef(double **a, int n, double offset=.01); //Make matrix +def via replacing a by a - (lmin+offset) I, where lmin is smallest eigenvalue of a
 void choldc(double **a, int n, double **aout, bool *posdef);   //Cholesky decomposition
 void choldc_inv(double **a, int n, double **aout, bool *posdef); //Inverse of chol(a)
 void cholS_inv(double **cholS, int n, double **cholSinv); //Inverse of cholS
 void choldc_inv_internal(double **cholS, int n);
 double choldc_det(double **chols, int n); //Determinant of a symmetric def+ using its Cholesky decomp
 double logcholdc_det(double **chols, int n); //log-determinant of a symmetric def+ using its Cholesky decomp
-void inv_posdef(double **a, int n, double **aout, bool *posdef); //Inverse of a symmetric, positive definite matrix
+void inv_posdef(double **a, int n, double **aout, bool *posdef, double **chola = NULL, double **cholainv = NULL); //Inverse of a symmetric, positive definite matrix
 void inv_posdef_upper(double **a, int n, double **aout, bool *posdef); //Same but only returns upper triangular elements
 void invdet_posdef(double **a, int n, double **aout, double *det_a); //Inverse and determinant of positive def matrix
 void inv_posdef_chol(double **invchol, int n, double **aout); //Inverse given cholesky decomposition
